@@ -238,7 +238,7 @@ impl OssCore {
         let mut m = parse_into_metadata(path, headers)?;
         let user_meta = parse_prefixed_headers(headers, X_OSS_META_PREFIX);
         if !user_meta.is_empty() {
-            m.with_user_metadata(user_meta);
+            m = m.with_user_metadata(user_meta);
         }
 
         Ok(m)
@@ -266,6 +266,8 @@ impl OssCore {
         // set sse headers
         req = self.insert_sse_headers(req);
 
+        let req = req.extension(Operation::Write);
+
         let req = req.body(body).map_err(new_request_build_error)?;
         Ok(req)
     }
@@ -294,6 +296,8 @@ impl OssCore {
         // set sse headers
         req = self.insert_sse_headers(req);
 
+        let req = req.extension(Operation::Write);
+
         let req = req.body(body).map_err(new_request_build_error)?;
         Ok(req)
     }
@@ -331,7 +335,6 @@ impl OssCore {
         }
 
         let mut req = Request::get(&url);
-        req = req.header(CONTENT_TYPE, "application/octet-stream");
 
         if !range.is_full() {
             req = req.header(RANGE, range.to_header());
@@ -361,6 +364,8 @@ impl OssCore {
             );
         }
 
+        let req = req.extension(Operation::Read);
+
         let req = req.body(Buffer::new()).map_err(new_request_build_error)?;
 
         Ok(req)
@@ -387,6 +392,8 @@ impl OssCore {
 
         let req = Request::delete(&url);
 
+        let req = req.extension(Operation::Delete);
+
         let req = req.body(Buffer::new()).map_err(new_request_build_error)?;
 
         Ok(req)
@@ -423,6 +430,9 @@ impl OssCore {
         if let Some(if_none_match) = args.if_none_match() {
             req = req.header(IF_NONE_MATCH, if_none_match);
         }
+
+        let req = req.extension(Operation::Stat);
+
         let req = req.body(Buffer::new()).map_err(new_request_build_error)?;
 
         Ok(req)
@@ -466,6 +476,7 @@ impl OssCore {
         }
 
         let req = Request::get(url.finish())
+            .extension(Operation::List)
             .body(Buffer::new())
             .map_err(new_request_build_error)?;
         Ok(req)
@@ -501,6 +512,8 @@ impl OssCore {
 
         req = req.header("x-oss-copy-source", source);
 
+        let req = req.extension(Operation::Copy);
+
         let mut req = req.body(Buffer::new()).map_err(new_request_build_error)?;
 
         self.sign(&mut req).await?;
@@ -552,6 +565,7 @@ impl OssCore {
         }
 
         let mut req = Request::get(url.finish())
+            .extension(Operation::List)
             .body(Buffer::new())
             .map_err(new_request_build_error)?;
 
@@ -592,6 +606,8 @@ impl OssCore {
         // Set content-md5 as required by API.
         let req = req.header("CONTENT-MD5", format_content_md5(content.as_bytes()));
 
+        let req = req.extension(Operation::Delete);
+
         let mut req = req
             .body(Buffer::from(Bytes::from(content)))
             .map_err(new_request_build_error)?;
@@ -631,6 +647,9 @@ impl OssCore {
             req = req.header(CACHE_CONTROL, cache_control);
         }
         req = self.insert_sse_headers(req);
+
+        let req = req.extension(Operation::Write);
+
         let mut req = req.body(Buffer::new()).map_err(new_request_build_error)?;
         self.sign(&mut req).await?;
         self.send(req).await
@@ -659,6 +678,9 @@ impl OssCore {
 
         let mut req = Request::put(&url);
         req = req.header(CONTENT_LENGTH, size);
+
+        let req = req.extension(Operation::Write);
+
         let mut req = req.body(body).map_err(new_request_build_error)?;
         self.sign(&mut req).await?;
         self.send(req).await
@@ -691,6 +713,8 @@ impl OssCore {
         // Set content-type to `application/xml` to avoid mixed with form post.
         let req = req.header(CONTENT_TYPE, "application/xml");
 
+        let req = req.extension(Operation::Write);
+
         let mut req = req
             .body(Buffer::from(Bytes::from(content)))
             .map_err(new_request_build_error)?;
@@ -716,6 +740,7 @@ impl OssCore {
         );
 
         let mut req = Request::delete(&url)
+            .extension(Operation::Write)
             .body(Buffer::new())
             .map_err(new_request_build_error)?;
         self.sign(&mut req).await?;
